@@ -1,5 +1,5 @@
 __title__ = 'RequestsThrottler'
-__version__ = '0.1.1'
+__version__ = '0.2.0'
 __author__ = 'Lou Marvin Caraig'
 __author_email__ = 'loumarvincaraig@gmail.com'
 __project_url__ = 'https://github.com/se7entyse7en/requests-throttler'
@@ -8,5 +8,6 @@ __copyright__ = 'Copyright 2013 Lou Marvin Caraig'
 
 
 from . import utils
-from .throttled_request.throttled_request import ThrottledRequest
-from .throttler.base_throttler import BaseThrottler
+from .throttled_request import ThrottledRequest
+from .throttler import BaseThrottler
+from .exceptions import *
